import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http';
import { CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { TestBed } from '@angular/core/testing';
import { MatDialogModule } from '@angular/material/dialog';
import { SwUpdate } from '@angular/service-worker';

import { TranslateModule } from '@ngstack/translate';
import { of } from 'rxjs';

import { InCoreModule, ObjectPropertyPipe, SnackBarService } from '../../../in-web-lib/src/lib/modules/in-core/in-core-module';
import { LoggerService, NoopLoggerService } from '../../../in-web-lib/src/lib/modules/in-logger/in-logger.module';
import { InUIModule } from '../../../in-web-lib/src/lib/modules/in-ui/in-ui.module';

import { AppComponent } from './app.component';

describe('AppComponent', () => {

    let swUpdate;
    let snackBarService;

    beforeEach(async () => {
        swUpdate = jasmine.createSpyObj('SwUpdate', ['versionUpdates', 'checkForUpdate', 'activateUpdate']);
        snackBarService = jasmine.createSpyObj('SnackBarService', ['showMessage', 'showSuccessMessage']);


        swUpdate.versionUpdates = of({
            type: 'VERSION_READY',
            current: { hash: 'sdgsdfgsfgsdf' },
            available: { hash: 'sdfsdf' }
        });
        swUpdate.checkForUpdate.and.rejectWith('Test Error');

        TestBed.configureTestingModule({
            declarations: [AppComponent],
            schemas: [CUSTOM_ELEMENTS_SCHEMA],
            imports: [
                TranslateModule.forRoot({
                    activeLang: 'en'
                }),
                InCoreModule,
                InUIModule,
                MatDialogModule
            ],
            providers: [
                { provide: SwUpdate, useValue: swUpdate },
                { provide: LoggerService, useFactory: () => new NoopLoggerService() },
                { provide: SnackBarService, useFactory: () => snackBarService },
                ObjectPropertyPipe,
                provideHttpClient(withInterceptorsFromDi())
            ]
        }).compileComponents().catch(error => fail(error));
    });

    it('should create the app', () => {
        const fixture = TestBed.createComponent(AppComponent);
        const app = fixture.debugElement.componentInstance;
        expect(app).toBeTruthy();
    });

    it('should initialize the app', async () => {
        TestBed.createComponent(AppComponent);
//        expect(platformSpy.ready).toHaveBeenCalled();
//        await platformReadySpy;
    });
});
